Skip to contents

Assert that the data.table package is available

Usage

.assert_data_table_available()

Value

Invisibly returns NULL if the check passes. Otherwise, throws an error.

Details

This function is used internally to ensure that the data.table package is available before attempting to use it. If data.table is not installed, an informative error message is thrown instructing the user to install the package.