Skip to contents

Computes the node-level metadata stored in each partykit::partynode(), including the weighted node size, tree depth, concentration index, and weighted outcome mean.

Usage

.ci_node_info(y, wt, depth, ci_fun)

Arguments

y

Two-column numeric matrix with rank and outcome.

wt

Non-negative case weights for the rows in y.

depth

Integer depth of the node, with the root at depth 0.

ci_fun

Concentration-index function created by ci_factory().

Value

A list of node metadata stored in the info slot of a party node.