Skip to contents

Extracts the rank/outcome response used by ci_tree() from a model frame. The preferred interface is a two-column response such as cbind(rank, outcome) ~ x1 + x2, but this helper can also recover named columns from the model frame when they are available.

Usage

.ci_tree_response(mf, rank_name, outcome_name)

Arguments

mf

A model frame produced from the ci_tree() formula and data.

rank_name

Name of the rank column to recover when the response is not already a two-column matrix.

outcome_name

Name of the outcome column to recover when the response is not already a two-column matrix.

Value

A numeric matrix with columns rank and outcome.