Skip to contents

Compute the reduction in concentration-index impurity obtained by splitting a parent node into left and right child nodes. The gain is the parent node's concentration-index score minus the weighted average of the two child-node scores.

Usage

weighted_ci_gain(y, wt, left, ci_fun)

Arguments

y

A matrix with two columns: SES rank variable and health outcome.

wt

A numeric vector of weights.

left

A logical vector indicating the left split.

ci_fun

A function to compute the concentration index.

Value

The weighted concentration-index gain.

Details

For concentration-index impurity I_m(.) based on index variant m, parent node t, and a candidate split creating left and right child nodes t_L and t_R, the gain is $$G_m(t, j, s) = I_m(t) - \frac{W_L}{W_t} I_m(t_L) - \frac{W_R}{W_t} I_m(t_R)$$ where W_t, W_L, and W_R are the total case weights in the parent, left child, and right child. Positive gain means the split reduces the weighted within-node concentration-index impurity.

In the greedy tree builder, the selected split at node t is the admissible variable-split pair with the largest gain: $$(j^*, s^*) = \arg\max_{j \in \mathcal{J}_t,\ s \in \mathcal{S}_{jt}} G_m(t, j, s).$$

References

Breiman L, Friedman JH, Olshen RA, Stone CJ (1984). Classification and Regression Trees. Wadsworth.

Wagstaff A, van Doorslaer E, Watanabe N (2003). "On Decomposing the Causes of Health Sector Inequalities with an Application to Malnutrition Inequalities in Vietnam." Journal of Econometrics, 112(1), 207-223. doi:10.1016/S0304-4076(02)00161-6.