Computes the concentration index of fitted risks or predicted outcomes. This
is not split gain, but it is useful for comparing inequality in predictions.
Usage
ci_prediction_index_vec(estimate, rank, case_weights = NULL, type = "CIg")
Arguments
- estimate
Numeric predictions. Used as the partition only when node
is NULL.
- rank
Socioeconomic rank values.
- case_weights
Optional non-negative case weights.
- type
One of "CI", "CIg", "CIc", or "L".
Value
A numeric concentration-index value.