Create controls for greedy concentration-index trees
Arguments
- minsplit
Minimum weighted node size required before attempting a split.
- minbucket
Minimum weighted child-node size.
- minprob
Minimum child-node weight proportion.
- maxdepth
Maximum tree depth, with the root at depth 0.
- min_gain
Minimum concentration-index gain required to split a node.
- min_relative_gain
Minimum concentration-index gain as a share of the parent-node impurity required to split a node.
- mtry
Optional number of variables sampled as candidates at each node.
- split_engine
Split-search implementation to use.
"cpp"uses the Rcpp-backed split search, while"R"uses the reference R implementation.- factor_split
Strategy for unordered factor split search.
"partition"evaluates binary partitions,"order"orders levels by weighted mean outcome and tries cumulative splits, and"auto"uses partition search when it is small enough and ordered search otherwise.- max_factor_levels_partition
Maximum number of observed factor levels eligible for partition search when
factor_split = "auto".- max_factor_partitions
Maximum number of binary factor partitions eligible for partition search when
factor_split = "auto".