Build descriptive information for one greedy CI tree node
Source:R/ci_tree_control.R
dot-ci_node_info.RdComputes the node-level metadata stored in each partykit::partynode(),
including the weighted node size, tree depth, concentration index, and
weighted outcome mean.
Arguments
- y
Two-column numeric matrix with
rankandoutcome.- wt
Non-negative case weights for the rows in
y.- depth
Integer depth of the node, with the root at depth 0.
- ci_fun
Concentration-index function created by
ci_factory().