Recover the two-column response for a greedy CI tree
Source:R/ci_tree_control.R
dot-ci_tree_response.RdExtracts the rank/outcome response used by ci_tree() from a model frame.
The preferred interface is a two-column response such as
cbind(rank, outcome) ~ x1 + x2, but this helper can also recover named
columns from the model frame when they are available.
Arguments
- mf
A model frame produced from the
ci_tree()formula and data.- rank_name
Name of the rank column to recover when the response is not already a two-column matrix.
- outcome_name
Name of the outcome column to recover when the response is not already a two-column matrix.