Prepare a SHAP table with named numeric columns Ensure that the input SHAP table is a data.table with named numeric columns. If the input is coercible to a data.table but has no column names, assign default names like "feature_1", "feature_2", etc. Validate that all columns are numeric and optionally check for missing values.
Source:R/assert_data_table_available.R
dot-prepare_named_shap_dt.RdPrepare a SHAP table with named numeric columns Ensure that the input SHAP table is a data.table with named numeric columns. If the input is coercible to a data.table but has no column names, assign default names like "feature_1", "feature_2", etc. Validate that all columns are numeric and optionally check for missing values.